@@ -2,18 +2,19 @@ use Object::Pad ':experimental(init_expr)';
 
 package OpenTelemetry::SDK::InstrumentationScope;
 
-our $VERSION = '0.024';
+our $VERSION = '0.025';
 
 class OpenTelemetry::SDK::InstrumentationScope :does(OpenTelemetry::Attributes) {
-    use OpenTelemetry;
+    use Log::Any;
 
     field $name    :param :reader;
     field $version :param :reader //= '';
 
+    my $logger = Log::Any->get_logger( category => 'OpenTelemetry' );
+
     ADJUST {
         $name ||= do {
-            OpenTelemetry->logger
-                ->warn('Created an instrumentation scope with an undefined or empty name');
+            $logger->warn('Created an instrumentation scope with an undefined or empty name');
             '';
         };
     }
